package com.macro.mall.tiny.modules.business.controller;


import com.macro.mall.tiny.common.api.CommonResult;
import com.macro.mall.tiny.domain.AdminUserDetails;
import com.macro.mall.tiny.modules.business.model.BFile;
import com.macro.mall.tiny.modules.business.model.BLine;
import com.macro.mall.tiny.modules.business.service.BLineService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.websocket.server.PathParam;
import java.util.List;

/**
 * <p>
 * 线路表 前端控制器
 * </p>
 *
 * @author macro
 * @since 2021-03-24
 */
@RestController
@Api(tags = "BLineController", description = "提供线路相关API")
@RequestMapping("/line")
public class BLineController {

    @Autowired
    private BLineService lineService;


    @ApiOperation("按照ID获取线路")
    @RequestMapping(value = "/{id}", method = RequestMethod.GET)
    @ResponseBody
    public CommonResult<BLine> getItem(@PathVariable Long id) {
        BLine line = lineService.getById(id);
        return CommonResult.success(line);
    }

    @ApiOperation("获取线路列表")
    @RequestMapping(value = "/list", method = RequestMethod.GET)
    @ResponseBody
    public CommonResult<List<BLine>> list() {
        List<BLine> lineList = lineService.getLineList();
        return CommonResult.success(lineList);
    }

    @ApiOperation("按照关键字查询线路列表")
    @RequestMapping(value = "/findByKey", method = RequestMethod.GET)
    @ResponseBody
    public CommonResult<List<BLine>> findByKey(@RequestParam @PathParam(value = "key") String key) {
        List<BLine> lineList = lineService.findByKey(key);
        return CommonResult.success(lineList);
    }

    @ApiOperation("获取线路文件资料")
    @RequestMapping(value = "/getFile/{id}", method = RequestMethod.GET)
    @ResponseBody
    public CommonResult<List<BFile>> getFile(@PathVariable Long id) {
        AdminUserDetails userDetails = (AdminUserDetails) SecurityContextHolder.getContext().getAuthentication().getPrincipal();
        List<BFile> data = lineService.getFile(id, userDetails);
        return CommonResult.success(data);
    }
}

