package com.macro.mall.tiny.modules.business.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.macro.mall.tiny.common.exception.Asserts;
import com.macro.mall.tiny.common.util.MyFileUtils;
import com.macro.mall.tiny.config.UploadConfig;
import com.macro.mall.tiny.domain.AdminUserDetails;
import com.macro.mall.tiny.modules.business.mapper.BProvinceMapper;
import com.macro.mall.tiny.modules.business.model.BFile;
import com.macro.mall.tiny.modules.business.model.BLine;
import com.macro.mall.tiny.modules.business.mapper.BLineMapper;
import com.macro.mall.tiny.modules.business.model.BProvince;
import com.macro.mall.tiny.modules.business.service.BLineCacheService;
import com.macro.mall.tiny.modules.business.service.BLineService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.macro.mall.tiny.security.util.AuthUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 线路表 服务实现类
 * </p>
 *
 * @author macro
 * @since 2021-03-24
 */
@Service
public class BLineServiceImpl extends ServiceImpl<BLineMapper, BLine> implements BLineService {

    @Autowired
    private BLineCacheService lineCacheService;

    @Autowired
    private BLineMapper lineMapper;

    @Autowired
    BProvinceMapper provinceMapper;

    @Override
    public List<BLine> getLineList() {
        List<BLine> lineList = lineCacheService.getLineList();
        if (CollUtil.isNotEmpty(lineList)) {
            return lineList;
        }
        lineList = lineMapper.findListMulti();
        if (CollUtil.isNotEmpty(lineList)) {
            lineCacheService.setLineList(lineList);
        } else {
            lineCacheService.setLineList(new ArrayList<>());
        }
        return lineList;
    }

    @Override
    public List<BLine> findByKey(String key) {
        return lineMapper.findListByKey(key);
    }

    @Override
    public List<BFile> getFile(Long id, AdminUserDetails userDetails) {
        boolean auth = AuthUtil.checkAccess(userDetails, AuthUtil.ACCESS);
        BLine line = lineMapper.selectById(id);
        if (line == null) Asserts.fail("该线路不存在，id：" + id);
        BProvince province = provinceMapper.selectById(line.getProvinceId());
        String basePath = UploadConfig.powerPath +
                province.getProvince() + UploadConfig.SEPARATOR +
                line.getName();
        return MyFileUtils.getSonFiles(basePath, auth);
    }
}
